/**
 * Inject a snippet of JavaScript into the page for execution in the context of the currently selected frame. The executed script is assumed to be asynchronous and the result of evaluating the script is returned to the client.
 *
 * Asynchronous script commands may not span page loads. If an unload event is fired while waiting for a script result, an error should be returned to the client.
 *
 * ```
 *    this.demoTest = function (browser) {
   *      browser.executeAsync(function(data) {
   *        // resize operation
   *        return true;
   *      }, [imagedata], function(result) {
   *        ...
   *      });
   *    };
 * ```
 *
 * @link /session/:sessionId/execute_async
 * @param {string|function} body The function body to be injected.
 * @param {Array} args An array of arguments which will be passed to the function.
 * @param {function} [callback] Optional callback function to be called when the command finishes.
 * @api protocol
 * @returns {*} The script result.
 */
Actions.executeAsync = function(script, args, callback) {
  args = Array.prototype.slice.call(arguments, 0);
  args.unshift('/execute_async');

  return executeHandler.apply(null, args);
};
